from tcsoa.gen.DocMgmtAw._2017_06.services import DocMgmtService as imp0
from tcsoa.base import TcService


class DocMgmtService(TcService):
    getPrinterDefinitions = imp0.getPrinterDefinitions
